@@ -59,6 +59,7 @@ static const gchar *_quark_strings[] = {
   "pad-chain-pre", "pad-chain-post", "pad-chain-list-pre",
   "pad-chain-list-post", "pad-send-event-pre", "pad-send-event-post",
   "memory-init", "memory-free-pre", "memory-free-post",
+  "pool-buffer-queued", "pool-buffer-dequeued",
 };
 
 GQuark _priv_gst_tracer_quark_table[GST_TRACER_QUARK_MAX];
@@ -305,9 +306,11 @@ _priv_gst_tracing_init (void)
         factory = GST_TRACER_FACTORY (gst_plugin_feature_load (feature));
         if (factory) {
           gst_tracer_utils_create_tracer (factory, t[i], params);
+          gst_object_unref (factory);
         } else {
           g_warning ("loading plugin containing feature %s failed!", t[i]);
         }
+        gst_object_unref (feature);
       } else if (t[i][0] != '\0') {
         g_warning ("no tracer named '%s'", t[i]);
       }
